
#ifndef _C137_dy6834_
#define _C137_dy6834_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F2592_32529(EIF_REFERENCE);
extern void EIF_Minit6834(void);

#ifdef __cplusplus
}
#endif

#endif
